@@ -1,7 +1,5 @@
-from ..utils.filesystem_utils import get_file_contents
 from ..utils.configuration import Configuration
 import asset
-from logging import getLogger
 
 class Report:
     class Status:
@@ -17,13 +15,11 @@ class Report:
 
     @staticmethod
     def __save_report(report, path):
-        getLogger(__name__).info(f"Saving report: '{report}'")
         with open(path, 'w') as f:
             f.write(report)
 
     @staticmethod
     def write_report(status: Status):
-        logger = getLogger(__name__)
         template = Report.__get_report_template()
         report = template.format(status=status)
         Report.__save_report(report, Report.REPORT_LOCATION)
