@@ -1,9 +1,9 @@
 from enum import Enum
-from .filesystem_utils import get_file_contents
 import json
+import asset
 
 class Configuration(dict):
-    CONFIGURATION_FILE_PATH = "./epalgorithmwrapper/configuration.json"
+    CONFIGURATION_FILE_PATH = "epalgorithmwrapper:configuration.json"
 
     class Key(Enum):
         INPUT_DIRECTORY="input-directory"
@@ -52,5 +52,5 @@ class Configuration(dict):
              
     @staticmethod
     def get_configuration():
-        configuration_str = get_file_contents(Configuration.CONFIGURATION_FILE_PATH)
+        configuration_str = asset.load(Configuration.CONFIGURATION_FILE_PATH).read()
         return Configuration(json.loads(configuration_str))
\ No newline at end of file
